const mongoose = require('mongoose');

class Database {
  constructor(url) {
    this.mongo = mongoose.connect(url);
    const schema = new mongoose.Schema({
      coin: { type: Number, default: 0, required: true },
      userId: { type: Number, required: true }
    });
    this.schema = mongoose.model('coin', schema);
  }

  async on(event, callback = (/* callback */) => {}) {
    if (event == 'ready') {
      return callback(null);
    } else if (event == 'error') {
      const error =  {
        code: 404,
        message: 'Bir hata oluştu, lütfen veritabanı oluşturucu yerine bakınız.',
        toString: () => 'GhostError: Bir hata oluştu, lütfen veritabanı oluşturucu yerine bakınız.'
      };
      return callback(error);
    }
  }

  async get(id) {
    return this.schema.findOne({ userId: id });
  }

  async set(id, number) {
    return this.schema.findOneAndUpdate({ userId: id }, { $set: { coin: number } });
  }

  async add(id, number) {
    return this.schema.findOneAndUpdate({ userId: id }, { $add: { coin: number } });
  }

  async subtract(id, number) {
    return this.schema.findOneAndUpdate({ userId: id }, { $delete: { coin: number } });
  }

  async delete(id) {
    return this.schema.deleteOne({ userId: id });
  }

  async push(id, number) {
    return this.schema.findOneAndUpdate({ userId: id }, { $push: { coin: number } });
  }
}

module.exports = Database;